# -*- coding: utf-8 -*-
"""
Fitbit API Library
------------------

:copyright: 2012-2014 ORCAS.
:license: BSD, see LICENSE for more details.
"""

from .api import Fitbit, FitbitOauthClient

# Meta.

__title__ = 'fitbit'
__author__ = 'Issac Kelly and ORCAS'
__author_email__ = 'bpitcher@orcasinc.com'
__copyright__ = 'Copyright 2012-2014 ORCAS'
__license__ = 'Apache 2.0'

__version__ = '0.1.0'

# Module namespace.

all_tests = []
